@@ -515,11 +515,19 @@ pub enum FilterMethod {
         #[structopt(
             long = "var",
             possible_values = &VariantType::iter().map(|v| v.into()).collect_vec(),
-            help = "Variant type to consider."
+            help = "Variant type to consider. When controlling global FDR (not using --local) this should \
+            be used to control FDR for each type separately. Otherwise, less certain variant types will be \
+            underrepresented."
         )]
-        vartype: VariantType,
+        vartype: Option<VariantType>,
         #[structopt(long, help = "FDR to control for.")]
         fdr: f64,
+        #[structopt(
+            long = "local",
+            help = "Control local FDR instead of global FDR. This means that for each record, the posterior \
+            of the selected events has to be at least 1-fdr."
+        )]
+        local: bool,
         #[structopt(long, help = "Events to consider.")]
         events: Vec<String>,
         #[structopt(long, help = "Minimum indel length to consider.")]
@@ -749,6 +757,7 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                             .heterozygosity(scenario.species().as_ref().map_or(None, |species| {
                                 species.heterozygosity().map(|het| LogProb::from(Prob(het)))
                             }))
+                            .variant_type_fractions(scenario.variant_type_fractions())
                             .build();
 
                         // setup caller
@@ -918,6 +927,7 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                 calls,
                 events,
                 fdr,
+                local,
                 vartype,
                 minlen,
                 maxlen,
@@ -927,11 +937,11 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                     .map(|event| SimpleEvent { name: event })
                     .collect_vec();
                 let vartype = match (vartype, minlen, maxlen) {
-                    (VariantType::Insertion(None), Some(minlen), Some(maxlen)) => {
-                        VariantType::Insertion(Some(minlen..maxlen))
+                    (Some(VariantType::Insertion(None)), Some(minlen), Some(maxlen)) => {
+                        Some(VariantType::Insertion(Some(minlen..maxlen)))
                     }
-                    (VariantType::Deletion(None), Some(minlen), Some(maxlen)) => {
-                        VariantType::Deletion(Some(minlen..maxlen))
+                    (Some(VariantType::Deletion(None)), Some(minlen), Some(maxlen)) => {
+                        Some(VariantType::Deletion(Some(minlen..maxlen)))
                     }
                     (vartype, _, _) => vartype,
                 };
@@ -940,8 +950,9 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                     &calls,
                     None,
                     &events,
-                    &vartype,
+                    vartype.as_ref(),
                     LogProb::from(Prob::checked(fdr)?),
+                    local,
                 )?;
             }
             FilterMethod::PosteriorOdds { ref events, odds } => {
@@ -1000,6 +1011,7 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                 let ploidies = ploidies.build();
 
                 let prior = Prior::builder()
+                    .variant_type_fractions(scenario.variant_type_fractions())
                     .ploidies(Some(ploidies))
                     .universe(Some(universes))
                     .uniform(sample_infos.uniform_prior)
